Draws each case as a rectangle by delegating to ggplot2::GeomRect. Exported so that other developers can extend it.
Format
A ggplot2::ggproto() object inheriting from ggplot2::Geom.
Draws each case as a rectangle by delegating to ggplot2::GeomRect. Exported so that other developers can extend it.
A ggplot2::ggproto() object inheriting from ggplot2::Geom.